@@ -422,6 +422,17 @@ static void create_channel(McsPlugin * mcs_plugin)
         mcs_manager_set_int(mcs_plugin->manager, "Taskbar/ShowPager", CHANNEL, show_pager ? 1 : 0);
     }
 
+    setting = mcs_manager_setting_lookup(mcs_plugin->manager, "Taskbar/ShowTray", CHANNEL);
+    if(setting)
+    {
+        show_tray = (setting->data.v_int ? TRUE : FALSE);
+    }
+    else
+    {
+        show_tray = TRUE;
+        mcs_manager_set_int(mcs_plugin->manager, "Taskbar/ShowTray", CHANNEL, show_pager ? 1 : 0);
+    }
+
     setting = mcs_manager_setting_lookup(mcs_plugin->manager, "Taskbar/ShowAllTasks", CHANNEL);
     if(setting)
     {
